@@ -9,7 +9,6 @@ from dnsimple.struct.dnssec import Dnssec
 from dnsimple.struct.delegation_signer_record import DelegationSignerRecord, DelegationSignerRecordInput
 from dnsimple.struct.domain import Domain
 from dnsimple.struct.domain_check import DomainCheck
-from dnsimple.struct.domain_premium_price import DomainPremiumPrice, DomainPremiumPriceOptions
 from dnsimple.struct.domain_price import DomainPrice
 from dnsimple.struct.domain_registration import DomainRegistration, DomainRegistrationRequest
 from dnsimple.struct.domain_renewal import DomainRenewal, DomainRenewRequest
@@ -28,7 +27,7 @@ from dnsimple.struct.user import User
 from dnsimple.struct.vanity_name_server import VanityNameServer
 from dnsimple.struct.webhook import Webhook
 from dnsimple.struct.whoami import Whoami
-from dnsimple.struct.whois_privacy import WhoisPrivacy, WhoisPrivacyRenewal
+from dnsimple.struct.whois_privacy import WhoisPrivacy
 from dnsimple.struct.zone import Zone
 from dnsimple.struct.zone_distribution import ZoneDistribution
 from dnsimple.struct.zone_file import ZoneFile
